
# Type: has zygosity




URI: [biolink:has_zygosity](https://w3id.org/biolink/vocab/has_zygosity)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Zygosity](Zygosity.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Genotype](Genotype.md)
